========================
django-codenerix-vending
========================

Codenerix Vending is a module that enables `CODENERIX <http://www.codenerix.com/>`_ to work as a Point Of Sales system focused for business faced to final client (services, supermarkets & shops, examples: retaurants, petrol stations, clothes shops, grocery store, hardware store and others).

.. image:: http://www.codenerix.com/wp-content/uploads/2018/05/codenerix.png
    :target: http://www.codenerix.com
    :alt: Try our demo with Codenerix Cloud

****
Demo
****

Coming soon...

**********
Quickstart
**********

1. Install this package::

    For python 2: sudo pip2 install django-codenerix-vending
    For python 3: sudo pip3 install django-codenerix-vending

2. Add "codenerix_vending" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'codenerix_vending',
    ]

3. Add in settings the params::

    # add legal terms image to be printed on tickets from thermal printer
    INFO_TERMS_VENDING = "img/terms_ticket_vending.png"

4. Since Codenerix Vending is a library, you only need to import its parts into your project and use them.

*************
Documentation
*************

Coming soon... do you help us? `Codenerix <http://www.codenerix.com/>`_

You can chat with us `here <https://goo.gl/NgpzBh>`_.

*******
Credits
*******

This project has been possible thanks to `Centrologic <http://www.centrologic.com/>`_.
